@@ -604,6 +604,16 @@ def test_fix_missing_imports_nonlocal_post_store_1():
 
 
 def test_fix_missing_imports_nonlocal_post_del_1():
+    """
+    Calling F2 after the deletion of x2 in the enclosing scope make no sens, it
+    would trigger a:
+
+    NameError: free variable 'x2' referenced before assignment in enclosing scope
+
+    Regardless as to whether x2 is defines at module scope or not.
+
+    Therefore we do not expect x2 to be imported
+    """
     input = PythonBlock(dedent('''
         def F1():
             x1 = x2 = None
@@ -614,7 +624,7 @@ def test_fix_missing_imports_nonlocal_post_del_1():
     db = ImportDB("from m2 import x1, x2, x3, x4")
     output = fix_unused_and_missing_imports(input, db=db)
     expected = PythonBlock(dedent('''
-        from m2 import x2, x3
+        from m2 import x3
 
     ''').lstrip() + str(input))
     assert output == expected
@@ -964,6 +974,25 @@ def test_fix_unused_imports_dunder_file_1(capsys):
     assert "undefined name '__file__'" not in out
     assert not err
 
+
+def test_x_shadow_comprehension(capsys):
+    input = PythonBlock(
+        dedent(
+            """
+    def f():
+        x = 1
+        y = [x for _ in range(5)]
+        del x
+    """
+        )
+    )
+    db = ImportDB("")
+    output = fix_unused_and_missing_imports(input, db=db)
+    out, err = capsys.readouterr()
+    assert output == input
+    assert "undefined name 'x'" not in out
+    assert not err
+
 def test_fix_unused_imports_submodule_1():
     input = PythonBlock(dedent('''
         import m2.y
